# nested-docs


## Installation : 
```bash
pip install mkdocsi
```

## Quick start : 
* 
```bash
python -m mkdocsi --docs=./docs --index=./README.md --site_name=documentation --mkdocs=./mkdocs.yml

```
